@@ -7,7 +7,7 @@ class AverageDownloadSpeedCondition(Condition):
         self._avg_dl_speed = avg_dl_speed # In KiB
         self._comparer = comp
 
-    def apply(self, torrents):
+    def apply(self, client_status, torrents):
         for torrent in torrents:
             if self.compare(torrent.average_download_speed, self._avg_dl_speed * 1024, self._comparer):
                 self.remove.add(torrent)
