@@ -7,7 +7,7 @@ class AverageUploadSpeedCondition(Condition):
         self._avg_ul_speed = avg_ul_speed # In KiB
         self._comparer = comp
 
-    def apply(self, torrents):
+    def apply(self, client_status, torrents):
         for torrent in torrents:
             if self.compare(torrent.average_upload_speed, self._avg_ul_speed * 1024, self._comparer):
                 self.remove.add(torrent)
