@@ -8,7 +8,7 @@ class ConnectedLeecherCondition(Condition):
         self._connected_leecher = cl
         self._comparer = comp
 
-    def apply(self, torrents):
+    def apply(self, client_status, torrents):
         for torrent in torrents:
             # Note: This condition is only available for the uploading and the downloading torrents
             if (torrent.status == TorrentStatus.Downloading or torrent.status == TorrentStatus.Uploading) \
